import adminapi from '@/api/system/admin'
import storage from '@/utils/storage'

const KEY_MENU_SELECTED = 'menu_selected'
const KEY_PROJECT_SELECTED = 'global_project_selected'
const KEY_PAGE_BRANDCRUMB = 'page_brandcrumb'

export default {
    namespaced: true,
    state: {
        sidebarClosed: false,
        sidebarSelected: '', // sidebar选中的选项
        userInfo: { username: 'admin' },
        permissions: {"system:role:delete": true, "system:role:create": true, "system:role:query": true, "system:role:setOpts": true},
        currentProjectId: null,
        projects: [],
        breadcrumb: []
    },
    getters: {
        sidebarClosed: state => state.sidebarClosed,
        sidebarSelected: state => {
            if (!state.pageSidebarSelected) {
                let menu = storage.get(KEY_MENU_SELECTED)
                if (menu) {
                    state.pageSidebarSelected = menu
                }
            }
            return state.pageSidebarSelected
        },
        userInfo: state => state.userInfo,
        permissions: state => state.permissions,
        projects: state => state.projects,
        currentProjectId: state => {
            if (!state.currentProjectId) {
                let pid = storage.get(KEY_PROJECT_SELECTED)
                if (pid) {
                    state.currentProjectId = pid
                }
            }
            return state.currentProjectId
        },
        breadcrumb: state => {
            if (!state.breadcrumb) {
                let arr = storage.get(KEY_PAGE_BRANDCRUMB)
                if (arr) {
                    state.breadcrumb = arr
                }
            }
            return state.breadcrumb
        }
    },
    mutations: {
        setSidebarClosed: (state, val) => (state.sidebarClosed = val),
        setSidebarSelected: (state, val) => {
            state.sidebarSelected = val
            storage.set(KEY_MENU_SELECTED, val)
        },
        setCurrentProjectId: (state, val) => {
            state.currentProjectId = val
            storage.set(KEY_PROJECT_SELECTED, val)
        }
    },
    actions: {
        loadUserInfo({ state }) {
            return new Promise((resolve, reject) => {
                adminapi.loadUserInfo().then(resp => {
                    console.log('api load user info ', resp)
                    if (resp.result == 'success') {
                        state.userInfo = { username: resp.username }
                        state.permissions = {}
                        if (resp.permissions) {
                            resp.permissions.forEach(p => (state.permissions[p] = true))
                        }
                        state.projects = []
                        if (resp.projects) {
                            resp.projects.forEach(proj =>
                                state.projects.push({
                                    id: proj.projId,
                                    name: proj.projLocalName
                                })
                            )
                        }
                    } else {
                        state.userInfo = null
                    }
                    resolve(resp)
                })
                // let resp = {
                //     result: 'success',
                //     message: null,
                //     projects: [
                //         {
                //             projId: 'Pj4419000006',
                //             projName: '广东省东莞市市辖区0001项目',
                //             projLocalName: '厚街万科城市广场',
                //             longitude: '113.23',
                //             latitude: '23.16',
                //             distance: 500
                //         }
                //     ],
                //     permissions: [
                //         'system:role:delete',
                //         'system:role:create',
                //         'system:role:query',
                //         'system:role:setOpts',
                //         'system:role:update'
                //     ],
                //     username: 'fuguoyu'
                // }
                // if (resp.result == 'success') {
                //     state.userInfo = { username: resp.username }
                //     state.permissions = {}
                //     if (resp.permissions) {
                //         resp.permissions.forEach(p => (state.permissions[p] = true))
                //     }
                //     state.projects = []
                //     if (resp.projects) {
                //         resp.projects.forEach(proj =>
                //             state.projects.push({
                //                 id: proj.projId,
                //                 name: proj.projLocalName
                //             })
                //         )
                //     }
                // } else {
                //     state.userInfo = null
                // }
                // resolve(resp)
            })
        },
        setBreadcrumb: {
            root: true,
            handler({ state }, val) {
                state.breadcrumb = []
                state.breadcrumb = val
                storage.set(KEY_PAGE_BRANDCRUMB, val)
            }
        }
    }
}
